@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2023 Red Hat, Inc.
+ * Copyright (c) 2012-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -11,6 +11,7 @@
  */
 package org.eclipse.che.api.factory.server.gitlab;
 
+import static com.google.common.base.Strings.isNullOrEmpty;
 import static java.util.stream.Collectors.toList;
 
 import com.google.common.base.Joiner;
@@ -21,7 +22,6 @@ import java.util.List;
 import java.util.Set;
 import javax.inject.Inject;
 import javax.inject.Named;
-import org.eclipse.che.api.auth.shared.dto.OAuthToken;
 import org.eclipse.che.api.factory.server.scm.*;
 import org.eclipse.che.api.factory.server.scm.exception.ScmBadRequestException;
 import org.eclipse.che.api.factory.server.scm.exception.ScmCommunicationException;
@@ -29,7 +29,6 @@ import org.eclipse.che.api.factory.server.scm.exception.ScmItemNotFoundException
 import org.eclipse.che.commons.annotation.Nullable;
 import org.eclipse.che.commons.lang.StringUtils;
 import org.eclipse.che.inject.ConfigurationException;
-import org.eclipse.che.security.oauth.OAuthAPI;
 
 /** Gitlab OAuth token retriever. */
 public class GitlabUserDataFetcher extends AbstractGitUserDataFetcher {
@@ -48,9 +47,11 @@ public class GitlabUserDataFetcher extends AbstractGitUserDataFetcher {
       @Nullable @Named("che.integration.gitlab.server_endpoints") String gitlabEndpoints,
       @Nullable @Named("che.integration.gitlab.oauth_endpoint") String oauthEndpoint,
       @Named("che.api") String apiEndpoint,
-      PersonalAccessTokenManager personalAccessTokenManager,
-      OAuthAPI oAuthTokenFetcher) {
-    super(OAUTH_PROVIDER_NAME, personalAccessTokenManager, oAuthTokenFetcher);
+      PersonalAccessTokenManager personalAccessTokenManager) {
+    super(
+        OAUTH_PROVIDER_NAME,
+        isNullOrEmpty(gitlabEndpoints) ? "https://gitlab.com" : gitlabEndpoints,
+        personalAccessTokenManager);
     this.apiEndpoint = apiEndpoint;
     if (gitlabEndpoints != null) {
       this.registeredGitlabEndpoints =
@@ -70,10 +71,10 @@ public class GitlabUserDataFetcher extends AbstractGitUserDataFetcher {
   }
 
   @Override
-  protected GitUserData fetchGitUserDataWithOAuthToken(OAuthToken oAuthToken)
+  protected GitUserData fetchGitUserDataWithOAuthToken(String token)
       throws ScmItemNotFoundException, ScmCommunicationException, ScmBadRequestException {
     for (String gitlabServerEndpoint : this.registeredGitlabEndpoints) {
-      GitlabUser user = new GitlabApiClient(gitlabServerEndpoint).getUser(oAuthToken.getToken());
+      GitlabUser user = new GitlabApiClient(gitlabServerEndpoint).getUser(token);
       return new GitUserData(user.getName(), user.getEmail());
     }
     throw new ScmCommunicationException("Failed to retrieve git user data from Gitlab");
